#ifndef NT2_INCLUDE_CONSTANTS_THREE_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_THREE_HPP_INCLUDED

#include <nt2/constant/include/constants/three.hpp>

#endif
